@@ -4,7 +4,7 @@
     'name': 'Account Stock Continental',
     'name_de_DE': 'Buchhaltung Lagerbewertung Kontinentale Methode',
     'name_fr_FR': 'Gestion de stock continentale',
-    'version': '2.0.4',
+    'version': '2.2.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -28,7 +28,13 @@
         'account.xml',
     ],
     'translation': [
-        'de_DE.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
